@@ -13,11 +13,12 @@ class Service:
         
             try:
                 method = getattr(self, "_{}".format(name))
-                self.services[name] = method()
-            except Exception as e:
-                #traceback.print_exc(e)
+            except AttributeError as e:
+                traceback.print_exc(e)
                 print('服务未找到:{}'.format(name))
                 os._exit(1)
                 #raise Exception('服务未找到:{}'.format(name))
 
+            self.services[name] = method()
+
         return self.services.get(name)
